A Pelican Blog

# FILENAME_METADATA example

Some cool stuff!

# Other articles

1. # Second article

   This is some article, in english

   read more

2. # A markdown powered article

   You're mutually oblivious.

   a root-relative link to unbelievable a file-relative link to unbelievable

   read more

3. # Article 1

   Article 1

   read more

4. # Article 2

   Article 2

   read more

5. # Article 3

   Article 3

   read more

6. # This is a super article !

   Multi-line metadata should be supported as well as inline markup.

   read more

7. # Oh yeah !

   ## Why not ?

   After all, why not ? It's pretty simple to do it, and it will allow me to write my blogposts in rst ! YEAH !

   read more

8. # Unbelievable !

   Or completely awesome. Depends the needs.

   a root-relative link to markdown-article a file-relative link to markdown-article

   ## Testing sourcecode directive

       1
       formatter = self.options and VARIANTS[self.options.keys()[0]]

   ## Testing another case

   This will now have a line number in 'custom' since it's the default in pelican.conf, it ...

   read more

9. # The baz tag

   This article overrides the listening of the articles under the baz tag.

   read more

## social

- atom feed